<template>
    <div class="warning-info">
        <div class="header">
            <div class="header-title">最新告警信息</div>
        </div>
        <!-- <JProTable
            ref="tableRef"
            :request="handleSearch"
            :columns="table.columns"
            noPagination
            model="TABLE"
            v-model:expandedRowKeys="expandedRowKeys"
            :scroll="{ y: 500 }"
            :defaultParams="{
                paging: true,
                pageSize: 4,
                sorts: [
                    {
                        name: 'alarmTime',
                        order: 'desc',
                    },
                ]
            }"
            :params="params"
            :loading="tableLoading"
        >
            <template #orderNum="slotProps">
                        {{ JSON.stringify(slotProps) }}
            </template>            

    
            <template #alarmTime="slotProps">
                <span>{{
                    dayjs(slotProps.alarmTime).format(
                        'YYYY-MM-DD HH:mm:ss',
                    )
                }}</span>
            </template>

            <template #level="slotProps">
                <span>{{
                    data.defaultLevel.find(
                                (i) => i.level === slotProps.level,
                            )?.title || slotProps.level
                }}</span>
            </template>
        </JProTable> -->


        <j-table :columns="table.columns" :data-source="tableData" :pagination="false" size="small" :scroll="{ y: 203, x: 800 }">
            <template #bodyCell="{ column, record, index }">
                <template v-if="column.key === 'orderNum'">
                    <span>
                        {{ index + 1 }}
                    </span>
                </template>
                <template v-if="column.key === 'desc'">
                    <span style="width: 120px; white-space: nowrap; overflow: hidden; text-overflow: ellipsis;">{{
                        record.desc }}</span>
                </template>
                <template v-if="column.key === 'state'">
                    <span style="width: 120px; white-space: nowrap; overflow: hidden; text-overflow: ellipsis;">{{
                        record.state.text }}</span>
                </template>
                 <template v-if="column.key === 'alarmTime'">
                        <span>{{
                            dayjs(record.alarmTime).format(
                                'YYYY-MM-DD HH:mm:ss',
                            )
                        }}</span>
                </template>
                <template v-if="column.key === 'handleTime'">
                        <span>{{
                            dayjs(record.handleTime).format(
                                'YYYY-MM-DD HH:mm:ss',
                            )
                        }}</span>
                </template>
                <template v-if="column.key === 'level'">
                    <span>{{
                        data.defaultLevel.find(
                                    (i) => i.level === record.level,
                                )?.title || slotProps.level
                    }}</span>
                </template>
                <template v-if="column.key === 'action' && record.state.value==='warning'">
                    <a   @click="handleAction(record)">确认</a>
                    <j-divider type="vertical" />
                    <a>忽略</a>
                </template>
            </template>
        </j-table>
    </div>
    <WarningHandler
            :data="data"
            v-if="data.solveVisible"
            @closeSolve="closeSolve"
    />
</template>
<script lang="ts" name="WarningInfo" setup>

import { queryLevel } from '@/api/rule-engine/config';
import dayjs from 'dayjs';
import { getImage } from '@/utils/comm';
import { queryHistoryList } from '@/api/rule-engine/log';
import { storeToRefs } from 'pinia';
import { useAlarmStore } from '@/store/alarm';

import WarningHandler from './WarningHandler.vue';

const alarmStore = useAlarmStore();
const { data } = storeToRefs(alarmStore);
const getDefaulitLevel = () => {
    queryLevel().then((res:any) => {
        if (res.status === 200) {
            data.value.defaultLevel = res.result?.levels || [];
        }
    });
};
getDefaulitLevel();

const expandedRowKeys = ref<any>([]);
const tableLoading = ref(false);
const tableData = ref<any[]>([])

const props = defineProps({
    deviceId: {
        type: String,
        default: () => null
    }
});
const params = ref<Record<string, any>>({terms: [
                {
                    "column": "targetId",
                    "termType": "eq$not",
                    "value": props.deviceId,
                    "type": "and"
                }
            ]});

const table = reactive({
    columns: [
        {
            title: '序号',
            name:'orderNum',
            dataIndex: 'orderNum',
            key: 'orderNum',
        },
        {
            title: '级别',
            dataIndex: 'level',
            key: 'level',
            scopedSlots: true,
        },
        {
            title: '告警类型名称',
            dataIndex: 'alarmName',
            key: 'alarmName',
        },
        {
            title: '报警来源',
            dataIndex: 'sourceName',
            key: 'sourceName',
        },
        {
            title: '告警时间',
            dataIndex: 'alarmTime',
            key: 'alarmTime',
            scopedSlots: true,
        },
        {
            title: '处理状态',
            dataIndex: 'state',
            key: 'state',
        },
        {
            title: '最近处理时间',
            dataIndex: 'handleTime',
            key: 'handleTime',
        },
        // {
        //     title: '备注',
        //     dataIndex: 'memo',
        //     key: 'memo',
        // },
        {
            title: '操作',
            key: 'action',
            fixed: 'right',
            ellipsis: true,
            scopedSlots: true,
            // width: 125,
        },
    ],
});

onMounted(() => {
    if(props.deviceId){
        params.value = {terms: [
                    {
                        column: "targetType",
                        termType: "eq",
                        value: "device",
                        type: "and"
                    },
                    {
                        column: "targetId",
                        termType: "eq$not",
                        value: props.deviceId,
                        type: "and"
                    }
                ]}
    }else{
        params.value = {terms: [
                    {
                        column: "targetId",
                        termType: "eq$not",
                        value: "********",
                        type: "and"
                    }
                ]}
    }

    handleSearch();
   //initData();
});

// 假数据
const initData = () => {
    for (let index = 0; index < 20; index++) {
        tableData.value.push({
            id: index,
            level: "一级",
            position: "xxxxx",
            name: "xxxxx",
            type: "xxx",
            desc: "xxxxxxxxxxxxxx",
            warningTime: "2022-02-02 16:20:13",
            status: "xxx",
        });
    }
}

const handleAction = (currentData:any) => {
    data.value.current = currentData;
    data.value.solveVisible = true;
}

const closeSolve = () => {
    data.value.solveVisible = false;
    handleSearch();
};


//查询告警记录
import {    getDeviceList, query} from '@/api/rule-engine/log';
const handleSearch = async () => {
    const resp:any = await query(params.value);
    // if (resp.status === 200) {
    //     const res = await getOrgList();
    //     if (res.status === 200) {
    //         resp.result.data.map((item: any) => {
    //             if (item.targetType === 'org') {
    //                 res.result.forEach((item2: any) => {
    //                     if (item2.id === item.targetId) {
    //                         item.targetName = item2.name;
    //                     }
    //                     //targetName处理之后的
    //                     if (item.targetId === item.targetName) {
    //                         item.targetName = '无';
    //                     }
    //                 });
    //             }
    //         });
    //         return resp;
    //     }
    //}
    tableData.value = resp.result.data;
    return resp;
};


//查询告警日志
const queryList = async () => {
    //console.log("=====warning====queryList===========",props.deviceId)
    if(props.deviceId==null){
        return;
    }
    let params = {
            "pageIndex": 0,
            "pageSize": 12,
            "terms": [
                {
                    "column": "targetId",
                    "termType": "eq$not",
                    "value": props.deviceId,
                    "type": "and"
                }
            ],
            "sorts": [
                {
                    "name": "alarmTime",
                    "order": "desc"
                }
            ]
        }

    const res = await queryHistoryList({
        ...params,
        // sorts: [{ name: 'alarmTime', order: 'desc' }],
    });
    if (res.status === 200) {
        //console.log("===========res==========",res)
        // return {
        //     code: res.message,
        //     result: {
        //         data: res.result.data,
        //         pageIndex: res.result.pageIndex,
        //         pageSize: res.result.pageSize,
        //         total: res.result.total,
        //     },
        //     status: res.status,
        // };
    } else {
        return {
            code: 200,
            result: {
                data: [],
                pageIndex: 0,
                pageSize: 0,
                total: 0,
            },
            status: 200,
        };
    }
};


</script>
<style scoped lang="less">
.warning-info {
    width: 100%;
    margin-bottom: 16px;
    padding: 16px;
    height: 341px;
    background: #ffffff;
    box-shadow: 0px 2px 6px 0px #cccccc;
    border-radius: 4px 4px 4px 4px;
    .header {
        display: flex;
        align-items: center;
        justify-content: space-between;
        .header-title {
            border-left: 3px solid #3468ff;
            padding-left: 8px;
            font-size: 16px;
            font-family: PingFang SC-Medium, PingFang SC;
            font-weight: 500;
            color: #333333;
            line-height: 23px;
        }
    }
    
    .jtable-body-spin {
        padding: 0;
        max-height: 270px;
    }
}
</style>
